=======
Changes
=======

0.3
---

* Add option for permanent (301) redirects.
  [am-on]

0.2
---

* Support for structlog.
  [zupo]


0.1.1
-----

* Brown bag release.
  [zupo]


0.1
---

* Initial release. Based on https://pypi.python.org/pypi/pyramid_rewrite.
  [zupo]

